slepc-3.18.0 2022-10-01
Report Typos and Errors

# STGetSplitPreconditionerTerm

Gets the matrices associated with the split preconditioner.

### Synopsis

    #include "slepcst.h"
    PetscErrorCode STGetSplitPreconditionerTerm(ST st,PetscInt k,Mat *Psplit)

Not collective, though parallel Mats are returned if the ST is parallel

### Input Parameters

| st | - the spectral transformation context
| k | - the index of the requested matrix (starting in 0)

### Output Parameter

| Psplit | - the returned matrix

### See Also

STSetSplitPreconditioner(), STGetSplitPreconditionerInfo()

### Level

advanced

### Location

src/sys/classes/st/interface/stfunc.c
Index of all ST routines
Table of Contents for all manual pages
Index of all manual pages